==> spip_4.0.4.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Resetten',
	'boxstr_close' => 'Sluiten',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Volgende',
	'boxstr_previous' => 'Vorige',
	'boxstr_slideshowStart' => 'Diavoorstelling',
	'boxstr_slideshowStop' => 'Stoppen',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Geef de doelelementen die de box zullen activeren (uitgebreide CSS of jQuery uitdrukking)',
	'explication_selecteur_galerie' => 'Geef de doelelementen die zich in een galerij moeten bevinden (uitgebreide CSS of jQuery uitdrukking)',
	'explication_splash_url' => 'Geef de URL van de in een box te tonen media bij een eerste bezoek aan de site',
	'explication_traiter_toutes_images' => 'Een box op alle afbeeldingen instellen?',

	// L
	'label_active' => 'Mediabox activeren op het publieke site',
	'label_apparence' => 'Verschijning',
	'label_aucun_style' => 'Geen standaard stijl invoegen',
	'label_choix_transition_elastic' => 'Elastisch',
	'label_choix_transition_fade' => 'Cross fading',
	'label_choix_transition_none' => 'Zonder overgangseffect',
	'label_maxheight' => 'Max Hoogte (% of px)',
	'label_maxwidth' => 'Max breedte (% of px)',
	'label_minheight' => 'Min Hoogte (% of px)',
	'label_minwidth' => 'Min breedte (% of px)',
	'label_opacite' => 'Donkerheid achtergrond ',
	'label_selecteur_commun' => 'In het algemeen',
	'label_selecteur_galerie' => 'In galerij ',
	'label_skin' => 'Verschijning van de knopjes',
	'label_slideshow_speed' => 'Toontijd van de afbeeldingen in de diavoorstelling (ms)',
	'label_speed' => '
Overgangssnelheid (ms)',
	'label_splash' => 'Splash doos',
	'label_splash_height' => 'Hoogte (% of px)',
	'label_splash_url' => 'Te tonen URL',
	'label_splash_width' => 'Breedte (% of px)',
	'label_traiter_toutes_images' => 'Afbeeldingen',
	'label_transition' => 'Overgang tussen twee afbeeldingen',

	// T
	'titre_menu_box' => 'Multimedia Box',
	'titre_page_configurer_box' => 'Configuratie van de Multimedia Box'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'Resetten',
	'boxstr_close' => 'Sluiten',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Volgende',
	'boxstr_previous' => 'Vorige',
	'boxstr_slideshowStart' => 'Diavoorstelling',
	'boxstr_slideshowStop' => 'Stoppen',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Geef de doelelementen die de box zullen activeren (uitgebreide CSS of jQuery uitdrukking)',
	'explication_selecteur_galerie' => 'Geef de doelelementen die zich in een galerij moeten bevinden (uitgebreide CSS of jQuery uitdrukking)',
	'explication_splash_url' => 'Geef de URL van de in een box te tonen media bij een eerste bezoek aan de site',
	'explication_traiter_toutes_images' => 'Een box op alle afbeeldingen instellen?',

	// L
	'label_active' => 'Mediabox activeren op het publieke site',
	'label_apparence' => 'Verschijning',
	'label_aucun_style' => 'Geen standaard stijl invoegen',
	'label_choix_transition_elastic' => 'Elastisch',
	'label_choix_transition_fade' => 'Cross fading',
	'label_choix_transition_none' => 'Zonder overgangseffect',
	'label_maxheight' => 'Max Hoogte (% of px)',
	'label_maxwidth' => 'Max breedte (% of px)',
	'label_minheight' => 'Min Hoogte (% of px)',
	'label_minwidth' => 'Min breedte (% of px)',
	'label_opacite' => 'Donkerheid achtergrond ',
	'label_selecteur_commun' => 'In het algemeen',
	'label_selecteur_galerie' => 'In galerij ',
	'label_skin' => 'Verschijning van de knopjes',
	'label_slideshow_speed' => 'Toontijd van de afbeeldingen in de diavoorstelling (ms)',
	'label_speed' => '
Overgangssnelheid (ms)',
	'label_splash' => 'Splash doos',
	'label_splash_height' => 'Hoogte (% of px)',
	'label_splash_url' => 'Te tonen URL',
	'label_splash_width' => 'Breedte (% of px)',
	'label_traiter_toutes_images' => 'Afbeeldingen',
	'label_transition' => 'Overgang tussen twee afbeeldingen',

	// T
	'titre_menu_box' => 'Multimedia Box',
	'titre_page_configurer_box' => 'Configuratie van de Multimedia Box',
];
